# Changelog

## [Unreleased]

## [0.54.0] - 2019-05-29

### Added

- Support eager mode with tensorflow backend

## [0.43.0] - 2019-05-12

### Added

- Support `tf.keras`

## [0.40.0] - 2019-04-29

### Added

- Add warmup optimizer

## [Older Versions]

### Added

- BERT implementation
- Load official model
- Tokenizer
- Demos
